package com.xkrs.controller;

import com.xkrs.dao.DataSourceDao;
import com.xkrs.dao.PictureDao;
import com.xkrs.encapsulation.PromptMessageEnum;
import com.xkrs.model.entity.DataSource;
import com.xkrs.model.qo.DataSourceQo;
import com.xkrs.service.DataSourceService;
import com.xkrs.util.DataSourceQuery;
import org.apache.http.util.TextUtils;
import org.springframework.context.i18n.LocaleContextHolder;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.List;
import java.util.Locale;
import java.util.Map;

import static com.xkrs.encapsulation.OutputEncapsulation.outputEncapsulationObject;

/**
 * @Author: XinYi Song
 * @Date: 2022/1/19 17:05
 */
@RestController
public class DataSourceController {

    @Resource
    private DataSourceService dataSourceService;

    @Resource
    private DataSourceQuery dataSourceQuery;

    @Resource
    private DataSourceDao dataSourceDao;

    @Resource
    private PictureDao pictureDao;

    /**
     * 添加测量数据
     *
     * @param dataSourceQo
     * @return
     */
    @PostMapping("/insertDataSource")
    public String insertDataSource(@RequestBody DataSourceQo dataSourceQo) {
        return dataSourceService.insertDataSource(dataSourceQo);
    }

    /**
     * 查询某一产品的测量信息
     *
     * @param lotNo         批次号
     * @param machineNo     机器号
     * @param materialNo    物料号
     * @param modelNo       模具号
     * @param machineTypeNo 机种号
     * @param craftItemName 工艺项目名称
     * @return
     */
    @GetMapping("/selectDataSource")
    public String selectDataSource(@RequestParam(required = false, value = "lotNo") String lotNo, @RequestParam(required = false, value = "machineNo") String machineNo, @RequestParam(required = false, value = "materialNo") String materialNo, @RequestParam(required = false, value = "modelNo") String modelNo, @RequestParam(required = false, value = "machineTypeNo") String machineTypeNo, @RequestParam(required = false, value = "craftItemName") String craftItemName) {
        Locale locale = LocaleContextHolder.getLocale();
        List<Map<String, String>> groupList = dataSourceDao.selectAllDataSourceGroup();
        if (groupList == null || groupList.isEmpty()) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该产品的测量信息！", locale);
        }
        List<List<DataSource>> dataSourceListList = new ArrayList<>();
        for (Map<String, String> group : groupList) {
            String groupNameLotNo = group.get("lotNo");
            String groupNameMachineNo = group.get("machineNo");
            String groupNameMaterialNo = group.get("materialNo");
            String groupNameModelNo = group.get("modelNo");
            String groupNameMachineTypeNo = group.get("machineTypeNo");
            String groupNameCraftItemName = group.get("craftItemName");
            if (!TextUtils.isEmpty(lotNo) && !lotNo.equals(groupNameLotNo)) {
                continue;
            }
            if (!TextUtils.isEmpty(machineNo) && !machineNo.equals(groupNameMachineNo)) {
                continue;
            }
            if (!TextUtils.isEmpty(materialNo) && !materialNo.equals(groupNameMaterialNo)) {
                continue;
            }
            if (!TextUtils.isEmpty(modelNo) && !modelNo.equals(groupNameModelNo)) {
                continue;
            }
            if (!TextUtils.isEmpty(machineTypeNo) && !machineTypeNo.equals(groupNameMachineTypeNo)) {
                continue;
            }
            if (!TextUtils.isEmpty(craftItemName) && !craftItemName.equals(groupNameCraftItemName)) {
                continue;
            }
            List<DataSource> dataSourceList = dataSourceDao.selectDataSource(groupNameLotNo, groupNameMachineNo, groupNameMaterialNo, groupNameModelNo, groupNameMachineTypeNo, groupNameCraftItemName);
            if (dataSourceList != null && dataSourceList.size() > 0) {
                dataSourceListList.add(dataSourceList);
            }
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, dataSourceListList, locale);
    }

    /**
     * 查询全部的测量信息
     *
     * @return
     */
    @GetMapping("/selectAllSource")
    public String selectAllSource() {
        Locale locale = LocaleContextHolder.getLocale();
        List<DataSource> dataSources = dataSourceDao.findAll();
        if (dataSources.size() == 0) {
            return outputEncapsulationObject(PromptMessageEnum.DATA_NONE, "暂时没有该产品的测量信息！", locale);
        }
        return outputEncapsulationObject(PromptMessageEnum.SUCCESS, dataSources, locale);
    }
}
